==> google-events-0.3.4.tar.gz: google-events-0.3.4/src/google/events/cloud/certificatemanager_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.events.cloud.certificatemanager import gapic_version as package_version

__version__ = package_version.__version__



from .types.data import Certificate
from .types.data import CertificateEventData
from .types.data import CertificateIssuanceConfig
from .types.data import CertificateIssuanceConfigEventData
from .types.data import CertificateMap
from .types.data import CertificateMapEntry
from .types.data import CertificateMapEntryEventData
from .types.data import CertificateMapEventData
from .types.data import DnsAuthorization
from .types.data import DnsAuthorizationEventData
from .types.data import ServingState

__all__ = (
'Certificate',
'CertificateEventData',
'CertificateIssuanceConfig',
'CertificateIssuanceConfigEventData',
'CertificateMap',
'CertificateMapEntry',
'CertificateMapEntryEventData',
'CertificateMapEventData',
'DnsAuthorization',
'DnsAuthorizationEventData',
'ServingState',
)

==> google-events-0.9.0.tar.gz: google-events-0.9.0/src/google/events/cloud/certificatemanager_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.events.cloud.certificatemanager_v1 import gapic_version as package_version

__version__ = package_version.__version__



from .types.data import Certificate
from .types.data import CertificateEventData
from .types.data import CertificateIssuanceConfig
from .types.data import CertificateIssuanceConfigEventData
from .types.data import CertificateMap
from .types.data import CertificateMapEntry
from .types.data import CertificateMapEntryEventData
from .types.data import CertificateMapEventData
from .types.data import DnsAuthorization
from .types.data import DnsAuthorizationEventData
from .types.data import ServingState

__all__ = (
'Certificate',
'CertificateEventData',
'CertificateIssuanceConfig',
'CertificateIssuanceConfigEventData',
'CertificateMap',
'CertificateMapEntry',
'CertificateMapEntryEventData',
'CertificateMapEventData',
'DnsAuthorization',
'DnsAuthorizationEventData',
'ServingState',
)
